@@ -1,5 +1,5 @@
 package WWW::FetchStory::Fetcher::AO3;
-$WWW::FetchStory::Fetcher::AO3::VERSION = '0.2201';
+$WWW::FetchStory::Fetcher::AO3::VERSION = '0.2303';
 use strict;
 use warnings;
 =head1 NAME
@@ -8,7 +8,7 @@ WWW::FetchStory::Fetcher::AO3 - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.2201
+version 0.2303
 
 =head1 DESCRIPTION
 
@@ -141,7 +141,11 @@ sub parse_toc {
     $info{category} = $self->parse_category(%args);
     $info{rating} = $self->parse_rating(%args);
     $info{chapters} = $self->parse_chapter_urls(%args, sid=>$sid);
-    #$info{epub_url} = $self->parse_epub_url(%args, sid=>$sid);
+    my $epub_url = $self->parse_epub_url(%args, sid=>$sid);
+    if ($epub_url)
+    {
+        $info{epub_url} = $epub_url;
+    }
     if ($info{epub_url})
     {
         $info{wordcount} = $self->parse_wordcount(%args);
@@ -193,7 +197,7 @@ sub parse_epub_url {
     my $content = $args{content};
     my $sid = $args{sid};
     my $epub_url = '';
-    if ($content =~ m!href="(/downloads/[-\/\w]+/$sid/[^.]+\.epub)!)
+    if ($content =~ m!href="(/downloads/$sid/[^.]+\.epub)!)
     {
 	$epub_url = ("http://archiveofourown.org$1");
     }
@@ -310,6 +314,10 @@ sub parse_wordcount {
     {
 	$words = $1;
     }
+    elsif ($content =~ m!<dt class="words">Words:</dt><dd class="words">(\d+)</dd>!)
+    {
+	$words = $1;
+    }
     return $words;
 } # parse_wordcount
 
@@ -389,7 +397,7 @@ sub parse_universe {
     {
         $universe = 'Blakes 7';
     }
-    elsif ($universe =~ m!(Marvel Cinematic Universe|Avengers|Iron Man)!)
+    elsif ($universe =~ m!(Marvel Cinematic Universe|Avengers|Iron Man|Captain America)!)
     {
         $universe = 'MCU';
     }
